@@ -28,11 +28,19 @@ class Detect:
         self.pretrained_models = pretrained_models
         self.transformer = Bird_eye_view_Transformer(self.keypoints, self.keypoints_birds_eye_view, self.actual_length, self.actual_width, multi_pts = False)
     
-    def __call__(self, save_path, video = True, threshold = 0.5, need_view_tranformer = False, interval = 1, device = mx.gpu()):
+    def __call__(self, save_path, video = True, threshold = 0.5, need_view_tranformer = False, device = mx.gpu()):
+        '''
+        Parameters
+        ----------
+        save_path: path where the labelled video will be saved
+        video: if True, video detector will be used, otherwise, image detector will be used
+        threshold: bounding box with score larger than threshold will be kept
+        need_view_tranformer: if True, video frame will be transformed to bird-eye view for process
+        '''
         transformer = self.transformer if need_view_tranformer == True else None
         # detect_model = Bbox_detector('ssd_trained',)
         detect_model = Bbox_detector(self.pretrained_models, trained = self.trained, transformer = transformer, device = device)
-        detector = VideoDetector(detect_model, threshold = threshold, save_path = save_path, interval = interval) if video else ImageDetector(detect_model, threshold = threshold, save_path = save_path)
+        detector = VideoDetector(detect_model, threshold = threshold, save_path = save_path) if video else ImageDetector(detect_model, threshold = threshold, save_path = save_path)
         return detector
 
 
